=======
zemfrog
=======

.. image:: https://raw.githubusercontent.com/zemfrog/zemfrog/master/docs/_static/logo.png
    :target: https://zemfrog.readthedocs.io
    :alt: zemfrog logo

.. image:: https://img.shields.io/pypi/v/zemfrog.svg?style=for-the-badge
    :target: https://pypi.python.org/pypi/zemfrog

.. image:: https://img.shields.io/pypi/status/zemfrog.svg?style=for-the-badge
    :target: https://pypi.python.org/pypi/zemfrog/

.. image:: https://img.shields.io/pypi/dm/zemfrog?logo=python&style=for-the-badge
    :target: https://pypi.python.org/pypi/zemfrog/

.. image:: https://img.shields.io/travis/zemfrog/zemfrog.svg?style=for-the-badge
    :target: https://travis-ci.com/zemfrog/zemfrog

.. image:: https://readthedocs.org/projects/zemfrog/badge/?version=latest&style=for-the-badge
    :target: https://zemfrog.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status



Zemfrog is a simple framework based on flask for building a REST API quickly.
Which focuses on building a customizable, flexible and manageable REST API!

* Free software: MIT license
* Documentation: https://zemfrog.readthedocs.io.


Notes
-----

It should be noted. currently, the zemfrog project is still under development. So we are not responsible for the instability of the zemfrog API.


Features
--------

* Solid application structure.
* Automatically generate REST API.
* Built-in JWT authentication.
* Integrated with flask-apispec for building API documentation.
* Integrated with celery for background tasks.
* And much more...


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
